import click


@click.group(context_settings={'help_option_names': ['--help', '-h']})
def mlwcli():
    """Demo WP Control Help"""


@mlwcli.group()
def wp():
    """Commands for WP"""


@wp.command('install')
def wp_install():
    """Install WP instance"""


@click.pass_context
def wp_dup():
    """Duplicate WP instance"""


if __name__ == '__main__':
    mlwcli()



#!/usr/bin/env python
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

requirements = [
    'click'
]

setup(
    name='mlwcli',
    version='0.0.3',
    description='Command Line Interface for mlworks python package',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
                "Programming Language :: Python :: 3 :: Only",
                "Programming Language :: Python :: 3",
                "Programming Language :: Python :: 3.6",
                "Programming Language :: Python :: 3.7",
                "Programming Language :: Python :: 3.8",
                "License :: OSI Approved :: MIT License",
                "Operating System :: OS Independent",
                "Development Status :: 1 - Planning",
                "Natural Language :: Portuguese (Brazilian)",
                "Topic :: Scientific/Engineering :: Artificial Intelligence"],
    keywords=[
            "mlworks",
            "Python",
            "projects",
            "machine-learning",
            "feature-engineering",
            "modelling",
            "data-science"],
    url='https://github.com/adelmofilho/mlw-cli',
    author="Adelmo Filho",
    author_email="adelmo.aguiar.filho@gmail.com",
    license='MIT',
    python_requires='>=3.6',
    dependencies=['click'],
    packages=['mlwcli'],
    entry_points={
        'console_scripts': [
            'mlw=mlwcli.mlwcli:mlwcli'
        ]
    })
